@@ -8,7 +8,7 @@ use warnings;
 use Carp;
 use base qw{ Exporter };
 
-our $VERSION = '0.005_03';
+our $VERSION = '0.005_04';
 
 our @CARP_NOT = qw{
     PPIx::QuoteLike
@@ -27,14 +27,14 @@ our @CARP_NOT = qw{
 
 our @EXPORT_OK = qw{
     MINIMUM_PERL
-    SUFFICIENT_UTF8_SUPPORT
+    SUFFICIENT_UTF8_SUPPORT_FOR_WEIRD_DELIMITERS
     VARIABLE_RE
     @CARP_NOT
 };
 
 use constant MINIMUM_PERL	=> '5.000';
 
-use constant SUFFICIENT_UTF8_SUPPORT	=> $] ge '5.008001';
+use constant SUFFICIENT_UTF8_SUPPORT_FOR_WEIRD_DELIMITERS => $] ge '5.008003';
 
 # Match the name of a variable. The user of this needs to anchor it
 # right after the sigil. The line noise is [[:punct:]] as documented in
@@ -85,13 +85,14 @@ The minimum version of Perl understood by this parser, as a string. It
 is currently set to C<'5.000'>, since that is the minimum version of
 Perl accessible to the author.
 
-=head2 SUFFICIENT_UTF8_SUPPORT
+=head2 SUFFICIENT_UTF8_SUPPORT_FOR_WEIRD_DELIMITERS
 
 A Boolean which is true if the running version of Perl has UTF-8 support
 sufficient for our purposes.
 
-Currently that means C<5.8.1> or greater, with the specific requirements
-being C<use open qw{ :std :encoding(utf-8) }> and C</\p{Mark}/>.
+Currently that means C<5.8.3> or greater, with the specific requirements
+being C<use open qw{ :std :encoding(utf-8) }>, C</\p{Mark}/>, and the
+ability to parse things like C<qr \N{U+FFFF}foo\N{U+FFFF}>.
 
 =head2 VARIABLE_RE
 
